# CHANGELOG

<!-- version list -->

## v1.0.4 (2026-02-04)

### Bug Fixes

- **ci**: Checkout release tag for publish jobs
  ([`6b78004`](https://github.com/bhoshaga/struai/commit/6b78004629cee3dff309836f7879da417dd69ac9))


## v1.0.3 (2026-02-04)

### Bug Fixes

- Trigger release v1.0.3
  ([`a611906`](https://github.com/bhoshaga/struai/commit/a611906590f693d9222b2b95aa2c42830e92c156))

### Documentation

- Clarify auth and endpoints
  ([`9703efe`](https://github.com/bhoshaga/struai/commit/9703efe1354168cb32d3ed6eacea642e22bea593))


## v1.0.2 (2026-02-04)

### Bug Fixes

- **ci**: Add publish_only option for re-publishing
  ([`0806b1e`](https://github.com/bhoshaga/struai/commit/0806b1eb6dba6d518df9f43a199b9255d1776d6a))

- **ci**: Consolidate to single release workflow
  ([`91e94b0`](https://github.com/bhoshaga/struai/commit/91e94b00f5eb6e123adb2cfae01a473ed4cd5cbd))


## v1.0.1 (2026-02-04)

### Bug Fixes

- **ci**: Include publish jobs directly in release workflow
  ([`02436eb`](https://github.com/bhoshaga/struai/commit/02436eb55c63cbaa54eac8ca456a54d30125fada))


## v1.0.0 (2026-02-04)

- Initial Release
